Welcome to exporter's project
=============================


Exporter automates exporting projects from `FIT CTU GitLab <https://gitlab.fit.cvut.cz/>`_ to `GitHub <https://github.com/>`_.
It allows choosing which projects to export, their renaming, and visibility on GitHub.
Also, there is an option for exporting all of your GitLab projects at once.

See documentation `HERE <https://fit-ctu-gitlab-exporter.readthedocs.io/en/latest/>`_ for examples of how to use it.


.. image:: docs/img/example_run_gif.gif
